@@ -1,9 +1,8 @@
 import * as React from 'react';
 import { navFactory } from '@console/internal/components/utils';
 import { DetailsPage } from '@console/internal/components/factory';
-import { PodModel, TemplateModel } from '@console/internal/models';
-import { VMDisksFirehose } from '../vm-disks';
-import { VMNics } from '../vm-nics';
+import { PersistentVolumeClaimModel, PodModel, TemplateModel } from '@console/internal/models';
+import { VMDisksAndFileSystemsPage } from '../vm-disks/vm-disks';
 import {
   DataVolumeModel,
   VirtualMachineImportModel,
@@ -25,6 +24,8 @@ import { vmMenuActionsCreator } from './menu-actions';
 import { VMDashboard } from './vm-dashboard';
 import { TEMPLATE_TYPE_LABEL, TEMPLATE_TYPE_VM, VM_DETAIL_ENVIRONMENT } from '../../constants/vm';
 import { VMEnvironmentFirehose } from './vm-environment/vm-environment-page';
+import { VMNics } from '../vm-nics';
+import { PendingChangesWarningFirehose } from './pending-changes-warning';
 
 export const breadcrumbsForVMPage = (match: any) => () => [
   {
@@ -68,7 +69,7 @@ export const VirtualMachinesDetailsPage: React.FC<VirtualMachinesDetailsPageProp
   const disksPage = {
     href: VM_DETAIL_DISKS_HREF,
     name: 'Disks',
-    component: VMDisksFirehose,
+    component: VMDisksAndFileSystemsPage,
   };
 
   const environmentPage = {
@@ -77,6 +78,14 @@ export const VirtualMachinesDetailsPage: React.FC<VirtualMachinesDetailsPageProp
     component: VMEnvironmentFirehose,
   };
 
+  /* Disabled for 4.6 (BZ 1881125)
+  const snapshotsPage = {
+    href: VM_DETAIL_SNAPSHOTS,
+    name: 'Snapshots',
+    component: VMSnapshotsPage,
+  };
+  */
+
   const pages = [
     dashboardPage,
     overviewPage,
@@ -111,6 +120,12 @@ export const VirtualMachinesDetailsPage: React.FC<VirtualMachinesDetailsPageProp
       prop: 'vmImports',
       optional: true,
     },
+    {
+      kind: PersistentVolumeClaimModel.kind,
+      isList: true,
+      namespace,
+      prop: 'pvcs',
+    },
     {
       kind: DataVolumeModel.kind,
       isList: true,
@@ -131,7 +146,9 @@ export const VirtualMachinesDetailsPage: React.FC<VirtualMachinesDetailsPageProp
       resources={resources}
       breadcrumbsFor={breadcrumbsForVMPage(props.match)}
       customData={{ kindObj: VirtualMachineModel }}
-    />
+    >
+      <PendingChangesWarningFirehose name={name} namespace={namespace} />
+    </DetailsPage>
   );
 };
 
